@@ -1,7 +1,7 @@
 #!perl
 use strict;
 use warnings;
-use JSON::Mask;
+use Data::Partial::Google;
 use JSON::XS ();
 use FindBin;
 use Benchmark;
@@ -9,7 +9,7 @@ use Benchmark;
 open my $fixture_fh, '<', "$FindBin::Bin/../t/activities.json" or die $!;
 
 my $fixture = JSON::XS::decode_json(do { local $/; <$fixture_fh> });
-my $mask = JSON::Mask->new('url,object(content,attachments/url)');
+my $mask = Data::Partial::Google->new('url,object(content,attachments/url)');
 
 timethis(-3, sub {
 		my $out = $mask->mask($fixture);
